//#define XERR
#include "mri.ih"

double MRI::vSpecificity(double age) const
{
    return d_specificity.value();
}
